﻿using ShipyardContracts.BindingModels;
using ShipyardContracts.ViewModels;
using ShipyardDataModels.Enums;
using ShipyardDataModels.Models;
using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.Linq;
using System.Reflection;
using System.Runtime.Serialization;
using System.Text;
using System.Threading.Tasks;

namespace ShipyardListImplement.Models
{
    [DataContract]
    public class Order: IOrderModel
    {
        [DataMember]
        public int Id { get; private set; }

        [DataMember]
        public int ShipId { get; private set; }

        [DataMember]
        public int ClientId {get; private set; }

        [DataMember]
        public int? ImplementerId { get; private set; }

        [DataMember]
        public int Count { get; private set; }

        [DataMember]
        public double Sum { get; private set; }

        [DataMember]
        public OrderStatus Status { get; private set; } = OrderStatus.Неизвестен;

        [DataMember]
        public DateTime DateCreate { get; private set; }= DateTime.Now;

        [DataMember]
        public DateTime? DateImplement { get; private set; }

        public static Order? Create(OrderBindingModel? model)
        {
            if (model == null)
            {
                return null;
            }
            return new Order()
            {
                Id = model.Id,
                ShipId = model.ShipId,
                ClientId = model.ClientId,
                ImplementerId = model.ImplementerId,
                Count = model.Count,
                Sum = model.Sum,
                Status = model.Status,
                DateCreate = model.DateCreate,
                DateImplement = model.DateImplement
            };
        }
        public void Update(OrderBindingModel? model)
        {
            if (model == null)
            {
                return;
            }
            Status = model.Status;
            DateImplement = model.DateImplement;
        }
        public OrderViewModel GetViewModel => new()
        {
            Id = Id,
            ShipId = ShipId,
            ClientId = ClientId,
            ImplementerId = ImplementerId,
            Count = Count,
            Sum = Sum,
            Status = Status,
            DateCreate = DateCreate,
            DateImplement = DateImplement
        };

    }
}
